% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/system_configuration.r
\name{rawToSysConfig}
\alias{rawToSysConfig}
\title{Coerce raw data into a SysConfig class object}
\usage{
rawToSysConfig(x)
}
\arguments{
\item{x}{A vector of \code{raw} data that needs to be converted into an S3
\link{SysConfig} class object. It should have a length of at least 232. Although
system-configurations can be extended, such extended files are not supported here.}
}
\value{
Returns a \link{SysConfig} class object based on \code{x}.
}
\description{
\link{SysConfig} objects are comprehensive representations of binary Amiga
system-configuration files. Use this function to convert \code{raw} data from
such a file to a \link{SysConfig} object.
}
\details{
The Amiga used the system-configuration file to store certain system preferences
in a binary file. With this function such \code{raw} data can be converted into
a more comprehensive \link{SysConfig} object. Use \code{\link[AmigaFFH]{as.raw}}
to achieve the inverse.
}
\examples{
\dontrun{
## get the system-configuration from the adfExplorer example disk:
sc <- adfExplorer::get.adf.file(adfExplorer::adf.example, "devs/system-configuration")

## This will get you the raw data from the file:
typeof(sc)

## Convert the raw data to a more comprehensive named list (and S3 SysConfig class):
sc <- rawToSysConfig(sc)
}
}
\seealso{
Other SysConfig.operations: \code{\link{SysConfig}},
  \code{\link{read.SysConfig}},
  \code{\link{simpleSysConfig}},
  \code{\link{write.SysConfig}}

Other raw.operations: \code{\link{as.raw}},
  \code{\link{colourToAmigaRaw}}, \code{\link{packBitmap}},
  \code{\link{rawToAmigaBitmapFontSet}},
  \code{\link{rawToAmigaBitmapFont}},
  \code{\link{rawToAmigaIcon}},
  \code{\link{rawToHWSprite}}, \code{\link{rawToIFFChunk}},
  \code{\link{simpleAmigaIcon}}
}
\author{
Pepijn de Vries
}
